``pyramid_handlers``
====================

``pyramid_handlers`` is a package which allows Pyramid to largely emulate the
functionality of Pylons 1 "controllers".  Handlers are a synthesis of
Pyramid *url dispatch* and method introspection of a view class that makes it
easier to create bundles of view logic which reacts to particular route
patterns.

See `http://docs.pylonsproject.org/projects/pyramid_handlers/dev/
<http://docs.pylonsproject.org/projects/pyramid_handlers/dev/>`_ for
detailed documentation.

